function PIplot2(refdata, compdata, envOuter, envInner, PCIdata, cd)
% PIPLOT2 is called by PCI1H to make a PI diagram

% input:
%   refdata: array, 4 columns (year.dec, (transformed) y1 y2, month)
%   compdata: array, 4 columns (year.dec, (transformed) y1 y2, month)
%   envOuter: array, 2 columns - X and Y co-ords of outer envelope
%   envInner, array, 2 columns - X and Y co-ords of inner envelope
%   PCIdata, vector, 7 values: (1) and (2) - start and end dates;
%       (3) - PCI; (4) and (5) total N and N outside;
%       (6) - binomial probability; (7) chi-square
%   cd: structure (see cf2.m), in which the following fields are used:
%       cd.c1svt1 : is 1, data are cells/L, if 2, they are mm3 biomass/L
%       cd.COL : if 1, selects for colour and additional text
%       cd.df1n, cd.df2n : names of (external) data files 1, 2
%       cd.d1des, cd.d2des : descriptions of file 1 or 2 data sources
%       cd.mf : controls averaging or subsampling of comparison data
%       cd.mfref : if > 0.5, apply mf also to reference data
%       cd.ndf : number of data files
%       cp.p : 1-p is outlier fraction excluded from envelope
%       cd.reff : number of data file used as reference
%       cd.refs, cd.refe : start and finish years for reference
%       cd.un : short string, user initials NOT USED 7 SEP 15
%       cd.z1, cd.z2 : replaces zeros in files 1 or 2 
%       cd.sc : if 1, indicates that data have been scaled for envelope
% result is a two part diagram
%   left-hand part - reference data and envelope 
%   right-hand part - reference envelope and comparison data

% History and authorship:
%   originally, PCIPLOT
%   PT, 11-12 August 2008, using some code from PCI1ED2
%   PT, 9 August 2009, added cp.p, and minor changes to diagrams
%	PT, 25 August 2009, minor corrections
%   PT, 3 April 2010, minor updates
%   PT, 16 Aug 2011 - increased default max X (and Y)
%   PT, 29 April 2013 - better plots for biomass
%   PT, 20 May 2013 - draws lines for minima (NEEDS IMPROVEMENT)
%   PT, 6 Oct 2013 - better estimation of graph max and min
%   PT, 24 July 2015 - simplied BW output, changed print options
%   PT, 24 July 2015 - new version PIPLOT2, allowing variable seasons
%   PT, 4 Sep 2015 - simplified calculation of plot axes limits,
%                       allowing for their adjustment
%   PT, 7 Sep 2015 - fixed use of z1 and z2 instead of bz1 and bz2
%   PT, 12 Sep 2015 - displays 'PI' now, rather than 'PCI'
%   PT, 30 Sep 2015 - improves spacing of text
%   PT, 4 Oct 2015 - corrected labelling in two file case
%******************************************************************
%
global prog_name uname
%
WNTR = ismember(refdata(:,4),cd.Winter);
WNTC = ismember(compdata(:,4),cd.Winter);
WNText = ['\fontname{times}\fontsize{10}months ' num2str(cd.Winter)];
SPR = ismember(refdata(:,4),cd.Spring);
SPRC = ismember(compdata(:,4),cd.Spring);
SPText = ['\fontname{times}\fontsize{10}months ' num2str(cd.Spring)];
SUMR = ismember(refdata(:,4),cd.Summer);
SUMC = ismember(compdata(:,4),cd.Summer);
SUText = ['\fontname{times}\fontsize{10}months ' num2str(cd.Summer)];
AUT = ismember(refdata(:,4),cd.Autumn);
AUTC = ismember(compdata(:,4),cd.Autumn);
AUText = ['\fontname{times}\fontsize{10}months ' num2str(cd.Autumn)];
%
    clf;
	orient portrait;
	set(0, 'DefaultAxesFontName', 'times', 'DefaultAxesFontSize', 12);
%   in case cd.sc has not been set
    if not(isfield(cd, 'sc')), cd.sc = 0; end
% graph parameters (for square graphs) - updated 4 Sep 2015
    if cd.c1svt1 == 1, % using cell numbers as variable
        minX = cd.nmin; % see cf3 for calculation nmin
        maxX = cd.nmax; % can be changed in cf3 or run-time change option
     %   minX=2.0;maxX=8.0;% default - changed from 6 to 8 on 16 Aug 2011
    else % using biomass as the variable
        minX = cd.bmin; % see cf3 for calculation bmin
        maxX = cd.bmax; % can be changed in cf3 or run-time change option    
    %    minX=-5.0;maxX=2.0; % added 29 April 2013
    end
    if cd.COL > 0.5, maxX = maxX + 1; end % allow for extra text
    % adjust maxima and minima if necessary - NOT NOW NECESSARY
    % maxSV = max([max(refdata(:,2)) max(refdata(:,3)) ...
    %                max(compdata(:,2)) max(compdata(:,3))] );
    % if maxSV>maxX, maxX=ceil(maxSV); end
    maxY=maxX;
    % minSV = min([min(refdata(:,2)) min(refdata(:,3)) ...
    %                min(compdata(:,2)) min(compdata(:,3)) ...
    %                log10(cd.z1)]);
    % if minSV < minX, minX=floor(minSV); end
    minY=minX;
    % new 30 Sep 2015
    rangeY = maxY-minY;
    rangeX = maxX-minX;
    lsY = 0.05*rangeY;
    hsX = 0.05*rangeX;
   % top=maxY-0.5;% y-axis start value for legends
    top=maxY-0.1*rangeY;% y-axis start value for legends
   % edge=minX+0.3;% x-axis start value for legends
    edge=minX+0.1*rangeX;% x-axis start value for legends
    rightedge=0.45*minX + 0.55*maxX; % x-axis right-hand start value
%
% first diagram - reference conditions
	subplot(1,2,1);
    hold on;
    if cd.COL>0.5,
        plot(refdata(:,2), refdata(:,3), 'ro--');
        plot(refdata(WNTR,2), refdata(WNTR,3),'ro', 'MarkerFaceColor','b');
        plot(refdata(SPR,2), refdata(SPR,3),'ro', 'MarkerFaceColor','g');
        plot(refdata(SUMR,2), refdata(SUMR,3),'ro', 'MarkerFaceColor','y');
        plot(refdata(AUT,2), refdata(AUT,3),'ro', 'MarkerFaceColor','r');
    else
        plot(refdata(:,2), refdata(:,3), 'ko--');
    end
% plot envelope
    if cd.COL>0.5, cs='r'; else cs='k'; end
	plot(envOuter(:,1), envOuter(:,2), [cs '-'], 'LineWidth', 2);
    plot(envInner(:,1), envInner(:,2), [cs '-'], 'LineWidth', 2);
% final stuff
    axis([minX maxX minY maxY]);
    axis square;
    grid on;
% plot minima - updated 4 Sep 2015 to use both z1 and z2 
% and further updated 7 Sep 2015 to check for biomass or numbers
    if cd.c1svt1 == 1, % cell numbers
        lmin1 = log10(cd.z1); lmin2 = log10(cd.z2);
    else % biovolume
        lmin1 = log10(cd.bz1); lmin2 = log10(cd.bz2);
    end
    line([lmin1 maxX], [lmin2 lmin2],... parallel to X-axis
        'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
    line([lmin1 lmin1], [lmin2 maxY],... parallel to Y-axis
         'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
% % add some legend and axis labels 
    if cd.ndf > 1.5 & cd.reff > 1.5,
        refdes = cd.d2des;
    else
        refdes = cd.d1des; % either only 1 file, or reff = 1
    end
    refdes = ['Reference: ' refdes ...
        ' (' num2str(cd.refs) ' to ' num2str(cd.refe) ')'];
    dsv1 = ['log_{10}(' cd.dsv1 ')'];
    dsv2 = ['log_{10}(' cd.dsv2 ')'];
    if cd.mfref > 0.5, 
        mfmes = ' (ref & comp)'; 
    else
        mfmes = ' (comp only)';
    end
    if cd.COL>0.5,
        if cd.sc == 1, 
            text(edge, top,'\fontname{times}\fontsize{10}scaled');
        end
        text(rightedge, top, ...
            ['\fontname{times}\fontsize{10}mf: ' ...
                num2str(cd.mf) mfmes]);
        text(rightedge, top-1*lsY, ...
            ['\fontname{times}\fontsize{10}p: ' num2str(cd.p,'% 4.2f')]);
        text(rightedge, top-2*lsY, ...
            ['\fontname{times}\fontsize{10}points: ' ...
                num2str(length(refdata(:,1)),'% 6.0f')]);
        plot(edge, top-1*lsY, 'ro', 'MarkerFaceColor','b');
        text(edge+hsX, top-1*lsY, WNText, 'color', 'k');
        plot(edge, top-2*lsY, 'ro', 'MarkerFaceColor','g');
        text(edge+hsX, top-2*lsY, SPText, 'color', 'k');
        plot(edge, top-3*lsY, 'ro', 'MarkerFaceColor','y');
        text(edge+hsX, top-3*lsY, SUText, 'color', 'k');
        plot(edge, top-4*lsY, 'ro', 'MarkerFaceColor','r');
        text(edge+hsX, top-4*lsY, AUText, 'color', 'k');
        text(maxX-1,lmin2, ...
            '\fontname{times}\fontsize{10}min', 'color', 'r', ...
            'VerticalAlignment', 'bottom');
    end;
    title(['\fontname{times}\fontsize{14}', refdes]);
    xlabel(['\fontname{times}\fontsize{12}' dsv1]);
	ylabel(['\fontname{times}\fontsize{12}' dsv2]);
%
% plot comparison data in second diagram
	subplot(1,2,2);
    hold on;
	if cd.COL > 0.5,
        plot(compdata(:,2), compdata(:,3), 'bo--');
        plot(compdata(WNTC,2),compdata(WNTC,3),'bo','MarkerFaceColor','b');
        plot(compdata(SPRC,2),compdata(SPRC,3),'bo','MarkerFaceColor','g');
        plot(compdata(SUMC,2),compdata(SUMC,3),'bo','MarkerFaceColor','y');
        plot(compdata(AUTC,2),compdata(AUTC,3),'bo','MarkerFaceColor','r');
    else
        plot(compdata(:,2), compdata(:,3), 'ko--');
    end
% plot envelope
 	if cd.COL>0.5, cs='r'; else cs='k'; end
 	plot(envOuter(:,1), envOuter(:,2), [cs '-'], 'LineWidth', 2);
    plot(envInner(:,1), envInner(:,2), [cs '-'], 'LineWidth', 2);
% plot minima - updated 4 Sep 2015 to use both z1 and z2
    % lmin1 and lmin2 already calculated
    line([lmin1 maxX], [lmin2 lmin2],... parallel to X-axis
        'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
    line([lmin1 lmin1], [lmin2 maxY],... parallel to Y-axis
         'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
% axis stuff etc
    grid on;
	axis([minX maxX minY maxY]);
    axis square;
% add some legend and axis labels	
    if cd.ndf > 1.5 & cd.compf > 1.5,
        compdes = cd.d2des;
        compfname = cd.df2n(1:4); % for output file name
    else
        compdes = cd.d1des; % either only 1 file, or compf = 1
        compfname = cd.df1n(1:4);
    end
    compdes = ['Comparison: ' compdes ...
        ' (' num2str(floor(PCIdata(1))) ' to ' ...
                num2str(floor(PCIdata(2))) ')'];
 	title(['\fontname{times}\fontsize{14}' compdes]);
 	xlabel(['\fontname{times}\fontsize{12}' dsv1]);
    if cd.COL > 0.5,
        text(edge,top, ['\fontname{times}\fontsize{10}drawn by ' ...
            prog_name ' on ' date]);
        text(edge,top-1*lsY, ['\fontname{times}\fontsize{10}\bfPI: ' ...
             num2str(PCIdata(3),'% 4.2f')]);
        text(edge,top-2*lsY, ['\fontname{times}\fontsize{10}new points: ' ...
             num2str(PCIdata(4),'% 5.0f')]);
% binomial probability
        text(rightedge,top-1*lsY, ...
            ['\fontname{times}\fontsize{10}binom p: '...
                num2str(PCIdata(6),'%6.4f')]);
% chi-square
        text(rightedge,top-2*lsY, ...
            ['\fontname{times}\fontsize{10}chi-sq: '...
                num2str(PCIdata(7),'%6.1f') ' (df=1)']);	
    end
%%   output the 2-part diagram
    if exist('cd.un', 'var'), uname = cd.un; end
    ofn = [uname, prog_name, '-', compfname, num2str(floor(PCIdata(1)))];
    
    PIPrint(cd.pt, ofn, 'PI diagram' ); % call printing function
end % of function
%

